# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-05-29 20:47
from __future__ import unicode_literals

import autoslug.fields
import colorful.fields
from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Conference',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('home', models.TextField(blank=True, default='')),
                ('venue', models.TextField(blank=True, default='')),
                ('city', models.CharField(blank=True, default='', max_length=64)),
                ('site', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='sites.Site')),
            ],
        ),
        migrations.CreateModel(
            name='Participant',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('name', models.CharField(max_length=128)),
                ('email', models.EmailField(max_length=254)),
                ('phone_number', models.CharField(blank=True, default='', max_length=16, verbose_name='Phone number')),
                ('biography', models.TextField(blank=True, verbose_name='Biography')),
                ('notes', models.TextField(blank=True, default='', help_text='This field is only visible by organizers.', verbose_name='Notes')),
                ('vip', models.BooleanField(default=False)),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sites.Site')),
            ],
        ),
        migrations.CreateModel(
            name='Talk',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('title', models.CharField(help_text='After submission, title can only be changed by the staff.', max_length=128, verbose_name='Title')),
                ('slug', autoslug.fields.AutoSlugField(editable=False, populate_from='title', unique=True)),
                ('description', models.TextField(blank=True, verbose_name='Description')),
                ('notes', models.TextField(blank=True, verbose_name='Message to organizers')),
                ('videotaped', models.BooleanField(default=True, verbose_name="I'm ok to be recorded on video")),
                ('video_licence', models.IntegerField(choices=[(1, 'CC-Zero'), (2, 'CC-BY'), (3, 'CC-BY-SA'), (4, 'CC-BY-ND'), (5, 'CC-BY-NC'), (6, 'CC-BY-NC-SA'), (7, 'CC-BY-NC-ND')], default=2, verbose_name='Video licence')),
                ('sound', models.BooleanField(default=False, verbose_name='I need sound')),
                ('accepted', models.NullBooleanField(default=None)),
                ('duration', models.PositiveIntegerField(default=0, verbose_name='Duration (min)')),
                ('plenary', models.BooleanField(default=False)),
            ],
            options={
                'ordering': ('category__id', 'title'),
            },
        ),
        migrations.CreateModel(
            name='TalkCategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=64)),
                ('duration', models.PositiveIntegerField(default=0, verbose_name='Default duration (min)')),
                ('color', colorful.fields.RGBColorField(default='#ffffff', verbose_name='Color on program')),
                ('label', models.CharField(blank=True, default='', max_length=64, verbose_name='Label on program')),
                ('opening_date', models.DateTimeField(blank=True, default=None, null=True)),
                ('closing_date', models.DateTimeField(blank=True, default=None, null=True)),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sites.Site')),
            ],
            options={
                'ordering': ('pk',),
            },
        ),
        migrations.CreateModel(
            name='Track',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('name', models.CharField(max_length=128, verbose_name='Name')),
                ('slug', autoslug.fields.AutoSlugField(editable=False, populate_from='name')),
                ('description', models.TextField(blank=True, verbose_name='Description')),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sites.Site')),
            ],
        ),
        migrations.CreateModel(
            name='Vote',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('vote', models.IntegerField(default=0, validators=[django.core.validators.MinValueValidator(-2), django.core.validators.MaxValueValidator(2)])),
                ('talk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='cfp.Talk')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AddField(
            model_name='talk',
            name='category',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='cfp.TalkCategory', verbose_name='Intervention kind'),
        ),
        migrations.AddField(
            model_name='talk',
            name='site',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sites.Site'),
        ),
        migrations.AddField(
            model_name='talk',
            name='speakers',
            field=models.ManyToManyField(to='cfp.Participant', verbose_name='Speakers'),
        ),
        migrations.AddField(
            model_name='talk',
            name='track',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='cfp.Track', verbose_name='Track'),
        ),
        migrations.AlterUniqueTogether(
            name='vote',
            unique_together=set([('talk', 'user')]),
        ),
        migrations.AlterUniqueTogether(
            name='track',
            unique_together=set([('site', 'name')]),
        ),
        migrations.AlterUniqueTogether(
            name='talkcategory',
            unique_together=set([('site', 'name')]),
        ),
        migrations.AlterUniqueTogether(
            name='participant',
            unique_together=set([('site', 'email')]),
        ),
    ]
